@@ -20,7 +20,7 @@
  * 
  */
 /**
-    File Name:          12.6.3-10.js
+    File Name:          12.6.3-11.js
     ECMA Section:       12.6.3 The for...in Statement
     Description:
     The production IterationStatement : for ( LeftHandSideExpression in Expression )
@@ -55,7 +55,7 @@
     Author:             christine@netscape.com
     Date:               11 september 1997
 */
-    var SECTION = "12.6.3-10";
+    var SECTION = "12.6.3-11";
     var VERSION = "ECMA_1";
     startTest();
     var TITLE   = "The for..in statment";
@@ -64,36 +64,18 @@
 
     var testcases = new Array();
 
-    //  for ( LeftHandSideExpression in Expression )
-    //  LeftHandSideExpression:NewExpression:MemberExpression
-
-    var count = 0;
-    function f() {     count++; return new Array("h","e","l","l","o"); }
+//    5.  Get the name of the next property of Result(3) that doesn't have the
+//        DontEnum attribute. If there is no such property, go to step 14.
 
     var result = "";
-    for ( p in f() ) { result += f()[p] };
+
+    for ( p in Number ) { result += String(p) };
 
     testcases[testcases.length] = new TestCase( SECTION,
-        "count = 0; result = \"\"; "+
-        "function f() { count++; return new Array(\"h\",\"e\",\"l\",\"l\",\"o\"); }"+
-        "for ( p in f() ) { result += f()[p] }; count",
-        6,
-        count );
-
-    testcases[testcases.length] = new TestCase( SECTION,
-        "result",
-        "hello",
+        "result = \"\"; for ( p in Number ) { result += String(p) };",
+        "",
         result );
 
-    //  LeftHandSideExpression:NewExpression:MemberExpression [ Expression ]
-    //  LeftHandSideExpression:NewExpression:MemberExpression . Identifier
-    //  LeftHandSideExpression:NewExpression:new MemberExpression Arguments
-    //  LeftHandSideExpression:NewExpression:PrimaryExpression:( Expression )
-    //  LeftHandSideExpression:CallExpression:MemberExpression Arguments
-    //  LeftHandSideExpression:CallExpression Arguments
-    //  LeftHandSideExpression:CallExpression [ Expression ]
-    //  LeftHandSideExpression:CallExpression . Identifier
-
     test();
 
 function test() {
@@ -109,4 +91,3 @@ function test() {
     stopTest();
     return ( testcases );
 }
-
